@@ -471,7 +471,7 @@ int vps_run_script(vps_handler *h, envid_t veid, char *script, vps_param *vps_p)
 			}
 		}
 		if ((ret = vz_env_create(h, veid, &vps_p->res, rd_p, wr_p,
-			NULL, NULL)))
+					NULL, NULL, NULL)))
 		{
 			return ret;
 		}
